# -*- coding: utf-8 -*-
"""
Created on Wed May 30 15:27:17 2018

@author: martindrech
"""

#from __future__ import absolute_import, division, print_function
import warnings
from messages import show_warning


daqfound = True

try:
    from mcculw import ul
    from mcculw.enums import DigitalIODirection, ULRange
    from examples.props.digital import DigitalProps
    from examples.props.ao import AnalogOutputProps

    from mcculw.ul import ULError

    ao_range = ULRange.BIP10VOLTS


except:
    warnings.warn('There was some error with the mcculw drivers. ')
    
    
    
try:
    d_props = DigitalProps(0)
    port = next(
                (port for port in d_props.port_info
                 if port.supports_output), None)
    ul.d_bit_in(0, port.type, 0)
    print('daq found')
except:
    #daqfound = False
    warnings.warn('daq not found')
    
#%%
        
class daq_DO(object):
    def __init__(self, out_num):
        global daqfound
        #ul.ignore_instacal()
        self.board_num = 0
        self.out_num = out_num
        if daqfound:
            self.digital_props = DigitalProps(self.board_num)
    
            # Find the first port that supports output, defaulting to None
            # if one is not found.
            self.port = next(
                (port for port in self.digital_props.port_info
                 if port.supports_output), None)
    
            # If the port is configurable, configure it for output
            if self.port != None and self.port.is_port_configurable:
                try:
                    ul.d_config_port(
                        self.board_num, self.port.type, DigitalIODirection.OUT)
                except ULError as e:
                    self.show_ul_error(e)
            print('puerto: ', self.port)
            print(self.port.type)
            
    if daqfound:
        def set_out(self, bit_value):
            try:
                # Output the value to the board
                ul.d_bit_out(self.board_num, self.port.type, self.out_num, bit_value)
            except ULError as e:
                self.show_ul_error(e)
    else:
        def set_out(self, bit_value):
            print('Digital out %i set to %s' % (self.out_num, bit_value) )
            return bit_value, self.out_num
                       
        
class daq_AO(object):
    def __init__(self, out_num):
        global daqfound
        
        #ul.ignore_instacal()
        self.board_num = 0
        self.out_num = out_num
        if daqfound:
            self.ao_props = AnalogOutputProps(self.board_num)
    if daqfound:
        def set_out(self, value):
            try:
                ul.v_out(self.board_num, self.out_num, ao_range, value)
            except ULError as e:
                self.show_ul_error(e)
            
            
        def get_analog_out(self):
            #ao_range = self.ao_props.available_ranges[0]
            try: 
                state = ul.a_in(self.board_num, self.out_num, ao_range)
                print(state)
            except ValueError:
                return 0
    else:
        def set_out(self, value):
            print('Analog out %i set to %f' % (self.out_num, value) )
            return value, self.out_num
######################################################################################
